<?php
/**
 * The Banner Slider Shortcode.
 *
 * @since      1.0.0
 * @package    Aheto
 * @subpackage Aheto\Shortcodes
 * @author     Upqode <info@upqode.com>
 */

use Aheto\Helper;

extract($atts);

$banners = $this->parse_group($cs_djo_modern_banners);

if (empty($banners)) {
    return '';
}

$this->generate_css();
$this->add_render_attribute('wrapper', 'id', $element_id);
$this->add_render_attribute('wrapper', 'class', $this->the_custom_classes());
$this->add_render_attribute('wrapper', 'class', 'aheto-banner-slider');
$this->add_render_attribute('wrapper', 'class', 'aheto-banner-slider--djo-modern');


/**
 * Set carousel params
 */
$carousel_params = Helper::get_carousel_params($atts, 'cs_swiper_');

/**
 * Set dependent style
 */
$sc_dir = DJO_T_URI . '/aheto/banner-slider/';
wp_enqueue_style('djo-banner-slider-modern', $sc_dir . 'assets/css/cs_layout1.css', null, null);
if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) : ?>
	<link href="<?php echo $sc_dir . 'assets/css/cs_layout1.css'?>" rel="stylesheet">
<?php endif;
?>
<div <?php $this->render_attribute_string('wrapper');?>>
	<div class="swiper">
		<div class="swiper-container swiper_aheto_diff_slider" <?php echo esc_attr($carousel_params); ?>>
			<div class="swiper-wrapper">
				<?php foreach ($banners as $banner):
					$banner = wp_parse_args($banner, [
						'cs_image' 			=> '',
						'cs_overlay' 		=> '',
						'cs_overlay_color'	=> '',
						'cs_title' 			=> '',
						'cs_desc' 			=> '',
						'cs_align' 			=> '',
						'cs_title_tag' 		=> ''
					]);
  					extract($banner);

					$cs_overlay = isset($cs_overlay) && !empty($cs_overlay) ? 'overlay-on' : '';
					$cs_title_tag = isset( $cs_title_tag ) ? $cs_title_tag : 'h1';

					if (!$cs_image) {
						continue;
					}

					$swiper_lazy_class = $cs_swiper_lazy ? ' swiper-lazy' : '';
					$background_image = Helper::get_background_attachment($cs_image, 'full', $atts, '', $cs_swiper_lazy); ?>

					<div class="swiper-slide">
						<div class="aheto-banner-slider-wrap cs-full-min-height-js s-back-switch <?php echo esc_attr($cs_align . $swiper_lazy_class); ?>" <?php echo esc_attr($background_image); ?>>
							
						<?php if ($cs_overlay): ?>
							<span class="aheto-banner-slider__overlay"
									style="background-color: <?php echo esc_attr($cs_overlay_color); ?>;"></span>
						<?php endif;?>

						<div class="aheto-banner-slider__content">
							
							<?php if ( ! empty( $cs_desc )) {?>
								<p class="aheto-banner-slider__desc aheto-subhead"><?php echo wp_kses_post($cs_desc); ?></p>
							<?php }

							if ( ! empty ( $cs_title )) {?>
								<<?php echo esc_attr( $cs_title_tag ); ?> class="aheto-banner__title"><?php echo wp_kses_post($cs_title); ?></<?php echo esc_attr( $cs_title_tag ); ?>>
							<?php }

							if ($cs_main_add_button) {?>
								<div class="aheto-banner-slider__links">
									<?php echo Helper::get_button($this, $banner, 'cs_main_'); ?>
								</div>
							<?php }?>

							</div>
						</div>
					</div>
				<?php endforeach;?>
			</div>
			<?php $this->swiper_pagination('cs_swiper_');?>
		</div>
		<?php if ( ! empty( $this->atts[ 'cs_swiper_arrows' ] ) ) { ?>
			<div class="swiper-button-prev">
				<svg xmlns="http://www.w3.org/2000/svg" width="34" height="37" viewBox="0 0 34 37">
					<defs>
						<mask id="lbn0b" width="2.05" height="2.04" x="-1.02" y="-1.02">
							<path fill="var(--c-light)" d="M3.4 3.4h26.2v30.2H3.4z" />
							<path d="M4 18.5l25 14.503V3.996z" />
						</mask>
						<filter id="lbn0a" width="57" height="61" x="-12" y="-12" filterUnits="userSpaceOnUse">
							<feOffset in="SourceGraphic" result="FeOffset1023Out" />
							<feGaussianBlur in="FeOffset1023Out" result="FeGaussianBlur1024Out" stdDeviation="2.16 2.16" />
						</filter>
						<clipPath id="lbn0c">
							<path fill="var(--c-light)" d="M4 18.5l25 14.503V3.996z" />
						</clipPath>
					</defs>
					<g>
						<g>
							<g filter="url(#lbn0a)">
								<path fill="none" stroke="var(--c-active)" stroke-opacity=".25" stroke-width="1.2" d="M4 18.5v0l25 14.503v0V3.996v0z" mask="url(&quot;#lbn0b&quot;)" />
								<path fill="var(--c-active)" fill-opacity=".25" d="M4 18.5l25 14.503V3.996z" />
							</g>
							<path class="path" fill="none" stroke="var(--c-active)" stroke-miterlimit="50" stroke-width="4" d="M4 18.5v0l25 14.503v0V3.996v0z" clip-path="url(&quot;#lbn0c&quot;)" />
						</g>
					</g>
				</svg>
			</div>
			<div class="swiper-button-next">
				<svg xmlns="http://www.w3.org/2000/svg" width="35" height="38" viewBox="0 0 35 38">
					<defs>
						<mask id="uok9b" width="2.05" height="2.04" x="-1.02" y="-1.02">
							<path fill="var(--c-light)" d="M4.4 3.4h27.2v31.2H4.4z" />
							<path d="M31 19L5.5 33.722V4.277z" />
						</mask>
						<filter id="uok9a" width="58" height="62" x="-11" y="-12" filterUnits="userSpaceOnUse">
							<feOffset in="SourceGraphic" result="FeOffset1051Out" />
							<feGaussianBlur in="FeOffset1051Out" result="FeGaussianBlur1052Out" stdDeviation="2.16 2.16" />
						</filter>
						<clipPath id="uok9c">
							<path fill="var(--c-light)" d="M31 19L5.5 33.722V4.277z" />
						</clipPath>
					</defs>
					<g>
						<g>
							<g filter="url(#uok9a)">
								<path fill="none" stroke="var(--c-active)" stroke-opacity=".25" stroke-width="1.2" d="M31 19v0L5.5 33.722v0V4.277v0z" mask="url(&quot;#uok9b&quot;)" />
								<path fill="var(--c-active)" fill-opacity=".25" d="M31 19L5.5 33.722V4.277z" />
							</g>
							<g filter="url(#uok9a)">
								<path fill="none" stroke="var(--c-active)" stroke-opacity=".25" stroke-width="1.2" d="M31 19v0L5.5 33.722v0V4.277v0z" mask="url(&quot;#uok9b&quot;)" />
								<path fill="var(--c-active)" fill-opacity=".25" d="M31 19L5.5 33.722V4.277z" />
							</g>
							<path class="path" fill="none" stroke="var(--c-active)" stroke-miterlimit="50" stroke-width="4" d="M31 19v0L5.5 33.722v0V4.277v0z" clip-path="url(&quot;#uok9c&quot;)" />
						</g>
					</g>
				</svg>
			</div>
		<?php } ?>
	</div>
</div>
