<?php
/**
 * The Contacts Shortcode.
 *
 * @since      1.0.0
 * @package    Aheto
 * @subpackage Aheto\Shortcodes
 * @author     Upqode <info@upqode.com>
 */

use Aheto\Helper;

extract( $atts );

$contacts = $this->parse_group($cs_contacts_group);

if ( empty($contacts) ) {
    return '';
}

$cs_dark_version = isset($cs_dark_version) && $cs_dark_version ? 'dark-version' : '';

$this->generate_css();

// Wrapper.
$this->add_render_attribute( 'wrapper', 'id', $element_id );
$this->add_render_attribute( 'wrapper', 'class', 'aheto-contact' );
$this->add_render_attribute( 'wrapper', 'class', 'aheto-contact--djo-modern' );
$this->add_render_attribute( 'wrapper', 'class', $cs_dark_version );
$this->add_render_attribute( 'wrapper', 'class', $this->the_custom_classes() );

/**
 * Set carousel params
 */
$carousel_default_params = [
    'speed' => 1000,
    'arrows' => true
]; // will use when not chosen option 'Change slider params' 

$carousel_params = Helper::get_carousel_params($atts, 'cs_contacts_', $carousel_default_params);

/**
 * Set dependent style
 */
$sc_dir = DJO_T_URI . '/aheto/contacts/';
wp_enqueue_style('djo-contacts-modern', $sc_dir . 'assets/css/cs_layout1.css', null, null);
if ( \Elementor\Plugin::$instance->editor->is_edit_mode() ) : ?>
	<link href="<?php echo $sc_dir . 'assets/css/cs_layout1.css'?>" rel="stylesheet">
<?php endif; ?>

<div <?php $this->render_attribute_string( 'wrapper' ); ?>>

    <div class="swiper">
        <div class="swiper-container swiper_aheto_diff_slider" <?php echo esc_attr($carousel_params); ?>>
            <div class="swiper-wrapper">
                <?php foreach ( $contacts  as $contact ) :
                    $contact = wp_parse_args($contact, [
                        'cs_heading_tag'         => '',
                        'cs_heading'         => '',
                        'cs_address'         => '',
                        'cs_phone'         => '',
                        'cs_email'          => '',
                    ]);
                    extract($contact);

                    ?>
                    <div class="swiper-slide">
                        <?php if ( ! empty( $contact['cs_heading'] ) ){ ?>
                            <h4 class="aheto-contact__title"><?php echo wp_kses_post( $contact['cs_heading'] ); ?></h4>
                        <?php } ?>

                        <?php if ( ! empty( $contact['cs_address'] ) ) : ?>
                            <div class="aheto-contact__info">
                                <i class="fa fa-map-marker"></i>
                                <p><?php echo wp_kses_post( $contact['cs_address'] ); ?></p>
                            </div>
						<?php endif; ?>
						
						<?php if ( ! empty( $contact['cs_phone'] ) ) : ?>
                            <div class="aheto-contact__info">
                                <i class="fa fa-phone"></i>
                                
                                <p><a class="aheto-contact__link" href="tel:<?php echo esc_attr( str_replace(" ","", $contact['cs_phone']) ); ?>"><?php echo esc_html( $contact['cs_phone'] ); ?></a></p>
                            </div>
                        <?php endif; ?>

                        <?php if ( ! empty( $contact['cs_email'] ) ) :
                            ?>
                            <div class="aheto-contact__info">
                                <i class="fa fa-envelope"></i>
                                <p><a class="aheto-contact__link" href="mailto:<?php echo esc_attr( $contact['cs_email'] ); ?>"><?php echo esc_html( $contact['cs_email']); ?></a></p>
                            </div>
                        <?php endif; ?>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
        <div class="aheto-contact__arrows-wrap">
	        <?php $this->swiper_arrow('cs_contacts_'); ?>
        </div>
    </div>
</div>
