<?php
/**
 * Djo functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Djo
 */

defined('DJO_T_URI') or define('DJO_T_URI', get_template_directory_uri());
defined('DJO_T_PATH') or define('DJO_T_PATH', get_template_directory());

require_once DJO_T_PATH . '/include/class-tgm-plugin-activation.php';
require_once DJO_T_PATH . '/include/custom-header.php';
require_once DJO_T_PATH . '/include/actions-config.php';
require_once DJO_T_PATH . '/include/helper-function.php';
require_once DJO_T_PATH . '/include/djo-custom-fields.php';
require_once DJO_T_PATH . '/include/customizer.php';

require DJO_T_PATH . '/vendor/autoload.php';



/**
 * Initialize the plugin tracker
 *
 * @return void
 */
function appsero_init_tracker_djo() {

	if ( ! class_exists( 'Appsero\Client' ) ) {
		require_once DJO_T_PATH . '/vendor/appsero/client/src/Client.php';
	}

	$client = new \Appsero\Client( '4e52cad2-9a4b-4f1f-9bbd-556d2f028b33', 'Djo', __FILE__ );

	// Active insights
	$client->insights()->init();

	// Active automatic updater
	$client->updater();

}

appsero_init_tracker_djo();



if (!function_exists('djo_setup')):

    function djo_setup()
{

        register_nav_menus(array('primary-menu' => esc_html__('Primary menu', 'djo')));
        load_theme_textdomain('djo', get_template_directory() . '/languages');

        add_theme_support('automatic-feed-links');
        add_theme_support('title-tag');
        add_theme_support('post-thumbnails');
        add_theme_support('html5', array('search-form', 'comment-form', 'comment-list', 'gallery', 'caption'));

        // Set up the WordPress core custom background feature.
        add_theme_support('custom-background', apply_filters('djo_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        )));

        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');

        add_theme_support('custom-logo', array(
            'height' => 250,
            'width' => 250,
            'flex-width' => true,
            'flex-height' => true,
        ));
		
		if ( function_exists('aheto') && !function_exists('foxThemeAheto')) :		
			add_action('admin_notices', 'djo_admin_notice');
		endif;
		
		remove_theme_support( 'widgets-block-editor' );
    }
endif;

add_action('after_setup_theme', 'djo_setup');

function djo_admin_notice(){

	 echo '<div class="notice notice-error">
			 <p>We recommend you update <strong>Aheto</strong> to latest version, please <a href="'. get_admin_url() .'themes.php?page=tgmpa-install-plugins&plugin_status=all" class="">Click Here</a>&nbsp;</p>
		 </div>';
		 
}
add_theme_support('post-formats', array('aside', 'gallery', 'link', 'image', 'quote', 'status', 'video', 'audio', 'chat'));

// Disable REST API link tag
remove_action('wp_head', 'rest_output_link_wp_head', 10);

/**
 * SVG Support
 */

function cc_mime_types($mimes)
{
    $mimes['svg'] = 'image/svg+xml';
    return $mimes;
}
add_filter('upload_mimes', 'cc_mime_types');

/**
 * CF7 Autofill
 */

add_filter('wpcf7_form_elements', 'imp_wpcf7_form_elements');
function imp_wpcf7_form_elements($content)
{
	$str_pos = strpos($content, 'type="number"');

	if ( $str_pos !== false ) {
		$content = substr_replace($content, ' autocomplete="off" ', $str_pos, 0);
	}

    return $content;
}

add_filter( 'aheto_template_kit_category', function () {
	return 'djo';
} );

add_filter( 'aheto_api_url', function () {
	return 'https://import.foxthemes.me/wp-json';
}, 10 );

function djo_export_data() {
	if(class_exists('Aheto\Template_Kit\API') ){

		$aheto_api = new Aheto\Template_Kit\API;

		$endpoint = '/aheto/v1/getThemeTemplate/4240';

		$response = $aheto_api->get_demodata($endpoint, false, false, true);


		return $response;
	}
}

add_filter( 'export_data', 'djo_export_data', 10 );



$shortcodes_dir = get_template_directory() .'/aheto';
$files = glob( $shortcodes_dir . '/*/controllers/*.php' );
foreach ( $files as $file ) {
	require_once( $file );
}
/**
 * Hiding unnecessary shortcodes
 */

add_filter('aheto_shortcodes_data', function ( $data ){
	unset($data['blockquote'], $data['features-slider'], $data['instagram'], $data['team'], $data['time-schedule'], $data['call-to-action'], $data['clients'],
	$data['contact-info'], $data['features-timeline'], $data['lists'], $data['portfolio-nav'], $data['pricing-tables'], $data['progress-bar'], $data['recent-posts'],
	$data['title-bar'], $data['navbar'] );
    return $data;
}, 10, 1);

if ( ! function_exists( 'djo_deactivate_layouts' ) ) :
    function djo_deactivate_layouts() {
        $current_options = Array(
            'aheto_banner-slider' => Array(
                'layout1',
			),
            'aheto_coming-soon' => Array(
                'layout1',
            ),
            'aheto_contents' => Array(
                'layout1',
            ),
            'aheto_contacts' => Array(
                'layout1',
                'layout2',
                'layout3',
			),
            'aheto_features-single' => Array(
                'layout1',
                'layout2',
                'layout3',
                'layout4',
                'layout5',
                'layout6',
                'layout7',
			),
            'aheto_features-tabs' => Array(
                'layout1',
			),
            'aheto_heading' => Array(
                'layout1',
                'layout2',
			),
            'aheto_custom-post-types' => Array(
                'layout1',
                'layout4',
			),
            'aheto_media' => Array(
                'layout1',
                'layout2',
                'layout3',
                'layout4',
			),
            'aheto_navigation' => Array(
                'layout1',
                'layout2',
                'layout3',
                'layout4',
                'layout5',
                'layout6',
                'layout7',
                'layout8',
			),
			'aheto_social-networks' => Array(
                'layout1',
                'layout2',
			),
			'aheto_team-member' => Array(
                'layout1',
                'layout2',
			),
			'aheto_testimonials' => Array(
                'layout1',
			),
			'aheto_contact-forms' => Array(
                'layout1',
                'layout2',
                'layout3',
                'layout4',
                'layout5',
			),
			'aheto_video-btn' => Array(
                'layout1',
			),
        );
        return $current_options;
    }
endif;
add_filter( 'aheto_active_leyouts', 'djo_deactivate_layouts', 10 );
function deprecated_plugin_admin_notice() {
	if(is_plugin_active( 'qodeblock/qodeblock.php')){ ?>
		<div data-dismissible="disable-done-notice-forever" class="updated notice notice-success is-dismissible">
      
		<p><?php _e( '<b>Qodeblock plugin has been deprecated since version 1.0.2</b>, instead of using Qodeblock plugin you can use <a  href="https://import.foxthemes.me/plugins/premium-plugins/quikblock.zip" target="_blank">Quikblock Plugin.</a>. Please make sure to take a backup before replacing plugin.'); ?></p>
		</div>
	<?php
	}
}
add_action( 'admin_notices', 'deprecated_plugin_admin_notice' );
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581327947&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        