<?php

require_once ABSPATH . 'wp-admin/includes/plugin.php';

/**
 * Create custom html structure for comments
 */
if ( !function_exists('djo_comment') ) {
	function djo_comment($comment, $args, $depth) {

		$GLOBALS['comment'] = $comment;

		switch ( $comment->comment_type ):
			case 'pingback':
			case 'trackback': ?>
				<div class="pinback">
					<span class="pin-title"><?php esc_html_e('Pingback: ', 'djo'); ?></span><?php comment_author_link(); ?>
					<?php edit_comment_link(esc_html__('(Edit)', 'djo'), '<span class="edit-link">', '</span>'); ?>

				<?php
				break;
			default:
				// generate comments
				?>
			<div <?php comment_class('djo-blog--single__comments-item'); ?> id="li-comment-<?php comment_ID(); ?>">
				<div id="comment-<?php comment_ID(); ?>" class="djo-blog--single__comments-item-wrap">
					<div class="djo-blog--single__comments-content">
                        <span class="person-img">
							<?php echo get_avatar($comment, '80', '', '', array('class' => 'img-person')); ?>
                        </span>
						<div class="comment-content">
							<div class="author-wrap">
								<div class="author">
									<?php 
										comment_author();
									?>
								</div>
								<?php comment_reply_link(
									array_merge($args,
										array(
											'reply_text' => esc_html__('Reply', 'djo'),
											'after'      => '',
											'depth'      => $depth,
											'max_depth'  => $args['max_depth']
										)
									)
								); ?>
							</div>

							<div class="comment-text">
								<?php comment_text(); ?>
							</div>

                            <div class="comment-date">
								<?php 
								//comment_date(get_option('date_format'));
									$comment_date = get_comment_date( 'j F');
									$comment_time = get_comment_date( 'H:i');
									echo esc_html($comment_date . ' at ' . $comment_time);	
								?>
                            </div>
						</div>
					</div>
				</div>
				<?php
				break;
		endswitch;
	}
}


/**
 * Filter for excerpt more string
 */

if ( !function_exists('djo_excerpt_more') ) {
	function djo_excerpt_more() {
		return ' ...';
	}

	add_filter('excerpt_more', 'djo_excerpt_more');
}

// function custom_excerpt_length( $length ) {
// 	return 15;
// }
// add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

/**
 * Header template
 */

if ( ! function_exists( 'djo_main_header_html' ) ) {
	function djo_main_header_html() {

	    $active_plugin = function_exists( 'aheto' );
	    $template_name = $active_plugin ? 'aheto' : 'theme';

		get_template_part( 'template-parts/' . $template_name . '-header' );

	}
}

add_action( 'djo_main_header', 'djo_main_header_html' );



/**
 * Footer template
 */

if ( ! function_exists( 'djo_main_footer_html' ) ) {
	function djo_main_footer_html() {

		$active_plugin = function_exists( 'aheto' );
		$template_name = $active_plugin ? 'aheto' : 'theme';

		get_template_part( 'template-parts/' . $template_name . '-footer' );

	}
}


add_action( 'djo_main_footer', 'djo_main_footer_html' );


/**
 * Posy views counter
 */

function gt_get_post_view() {
	$count 		= get_post_meta( get_the_ID(), 'post_views_count', true );
	$count  	= $count === '' ? $count = 0 : $count;
	$view_text 	= _nx( 'View', 'Views', $count, 'views', 'djo' );
	$result 	= $count . ' ' . $view_text;
    return $result;
}
function gt_set_post_view() {
    $key = 'post_views_count';
    $post_id = get_the_ID();
    $count = (int) get_post_meta( $post_id, $key, true );
	$count++;
    update_post_meta( $post_id, $key, $count );
}
function gt_posts_column_views( $columns ) {
    $columns['post_views'] = 'Views';
    return $columns;
}
function gt_posts_custom_column_views( $column ) {
    if ( $column === 'post_views') {
        echo gt_get_post_view();
    }
}
add_filter( 'manage_posts_columns', 'gt_posts_column_views' );
add_action( 'manage_posts_custom_column', 'gt_posts_custom_column_views' );

/**
 * ALT for wp users
 */

function crunchify_gravatar_alt($crunchifyGravatar) {
    if (have_comments()) {
        $alt = get_comment_author();
    }
    else {
        $alt = get_the_author_meta('display_name');
    }
    $crunchifyGravatar = str_replace('alt=\'\'', 'alt=\'Avatar for ' . $alt . '\' title=\'Gravatar for ' . $alt . '\'', $crunchifyGravatar);
    return $crunchifyGravatar;
}
add_filter('get_avatar', 'crunchify_gravatar_alt');


/**
 *
 * Adding new fields in user profile.
 *
 */

add_action( 'show_user_profile', 'extra_user_profile_fields' );
add_action( 'edit_user_profile', 'extra_user_profile_fields' );

function extra_user_profile_fields( $user ) { ?>
    <h3><?php _e("Extra profile information", 'djo'); ?></h3>

    <table class="form-table">
		<tr>
			<th><label for="facebook"><?php _e("Facebook", 'djo'); ?></label></th>
			<td>
				<input type="text" name="facebook" id="facebook" value="<?php echo esc_attr( get_the_author_meta( 'facebook', $user->ID ) ); ?>" class="regular-text" /><br />
				<span class="description"><?php _e("Please enter your facebook.", 'djo'); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="linkedin"><?php _e("Linkedin", 'djo'); ?></label></th>
			<td>
				<input type="text" name="linkedin" id="linkedin" value="<?php echo esc_attr( get_the_author_meta( 'linkedin', $user->ID ) ); ?>" class="regular-text" /><br />
				<span class="description"><?php _e("Please enter your linkedin.", 'djo'); ?></span>
			</td>
		</tr>
		<tr>
			<th><label for="instagram"><?php _e("Instagram", 'djo'); ?></label></th>
			<td>
				<input type="text" name="instagram" id="instagram" value="<?php echo esc_attr( get_the_author_meta( 'instagram', $user->ID ) ); ?>" class="regular-text" /><br />
				<span class="description"><?php _e("Please enter your instagram.", 'djo'); ?></span>
			</td>
		</tr>
		<tr>
		<th><label for="twitter"><?php _e("Twitter", 'djo'); ?></label></th>
			<td>
				<input type="text" name="twitter" id="twitter" value="<?php echo esc_attr( get_the_author_meta( 'twitter', $user->ID ) ); ?>" class="regular-text" /><br />
				<span class="description"><?php _e("Please enter your twitter.", 'djo'); ?></span>
			</td>
		</tr>
    </table>
<?php }

/**
 *
 * Save and update new fields in user profile.
 *
 */
if ( ! function_exists( 'djo_save_extra_profile_fields' ) ) {
    function djo_save_extra_profile_fields( $user_id ) {
        if ( ! current_user_can( 'edit_user', $user_id ) ) {
            return false;
        }
        update_user_meta( $user_id, 'facebook',  	esc_url( $_POST['facebook'] ) );
        update_user_meta( $user_id, 'linkedin',   	esc_url( $_POST['linkedin'] ) );
        update_user_meta( $user_id, 'instagram', 	esc_url( $_POST['instagram'] ) );
        update_user_meta( $user_id, 'twitter', 		esc_url( $_POST['twitter'] ) );
    }
}
add_action( 'personal_options_update', 'djo_save_extra_profile_fields' );
add_action( 'edit_user_profile_update', 'djo_save_extra_profile_fields' );

/**
 *
 * Excerpt length
 *
 */

function custom_excerpt_length( $length ) {
	return 15;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

/**
 * Aheto dependency
 */

function djo_add_dependency($id = '', $args = array(), $shortcode = '') {

	if ( is_array( $id ) ) {

		foreach ( $id as $slug ) {
			$param = (array)$shortcode->depedency[$slug]['template'];
			$shortcode->depedency[$slug]['template'] = array_merge($args, $param );
		}

	} else {
		$param = (array)$shortcode->depedency[$id]['template'];
		$shortcode->depedency[$id]['template'] = array_merge($args, $param );
	}

    return;
}